@@ -30,6 +30,11 @@ class X(object):
                     assert 'exceptions.AssertionError' not in test.message
                     assert 'backend.pastebin_loggedin' in test.alltext
                     assert 'python2.7' in test.alltext
+            if test.methodname == '003-passed-test':
+                assert "system output" in test.stdall
+                assert "error output" in test.stdall
+                assert "system output" in test.stdout
+                assert "error output" in test.stderr
 
     def test_hashes(self):
         """ assert hashes are unique """
@@ -75,3 +80,10 @@ class Test3(X, TestCase):
                 assert 'AssertionError' in f[1]
                 assert 'None' not in f[1]
                 assert f[0].message is None
+
+
+class Test4(X, TestCase):
+    FILENAME = 'test4.xml'
+
+    def test_props(self):
+        assert self.ts.properties['assert-passed'] == '1'
