@@ -17,6 +17,8 @@ class TestResult(unittest.TestResult):
 
 class TestCase(unittest.TestCase):
     TR_CLASS = TestResult
+    stdout = None
+    stderr = None
 
     def __init__(self, classname, methodname):
         super(TestCase, self).__init__()
@@ -108,9 +110,16 @@ class TestCase(unittest.TestCase):
     def bad(self):
         return not self.good
 
+    @property
+    def stdall(self):
+        """ All system output """
+        return '\n'.join([out for out in (self.stdout, self.stderr) if out])
+
 
 class TestSuite(unittest.TestSuite):
-    pass
+    def __init__(self, *args, **kwargs):
+        super(TestSuite, self).__init__(*args, **kwargs)
+        self.properties = {}
 
 
 class Parser(object):
@@ -119,27 +128,18 @@ class Parser(object):
     TR_CLASS = TestResult
 
     def parse(self, source):
-        ts = self.TS_CLASS()
-
         xml = ElementTree.parse(source)
         root = xml.getroot()
-        assert root.tag == 'testsuite'
-        for el in xml.getroot():
-            if el.tag == 'testcase':
-                if len(el) == 0:
-                    tc = self.TC_CLASS(el.attrib['classname'], el.attrib['name'])
-                    tc.seed('success', trace=el.text or None)
-                    tc.time = to_timedelta(el.attrib.get('time'))
-                    ts.addTest(tc)
-                for e in el:
-                    if e.tag in ('failure', 'error', 'skipped'):
-                        result = e.tag
-                        typename = e.attrib.get('type')
-                        message = e.attrib.get('message')
-                        tc = self.TC_CLASS(el.attrib['classname'], el.attrib['name'])
-                        tc.seed(result, typename, message, e.text or None)
-                        tc.time = to_timedelta(el.attrib.get('time'))
-                        ts.addTest(tc)
+        return self.parse_root(root)
+
+    def parse_root(self, root):
+        ts = self.TS_CLASS()
+        if root.tag == 'testsuites':
+            for subroot in root:
+                self.parse_testsuite(subroot, ts)
+        else:
+            self.parse_testsuite(root, ts)
+
         tr = ts.run(self.TR_CLASS())
 
         ts.name = root.attrib.get('name')
@@ -157,6 +157,42 @@ class Parser(object):
 
         return (ts, tr)
 
+    def parse_testsuite(self, root, ts):
+        assert root.tag == 'testsuite'
+        for el in root:
+            if el.tag == 'testcase':
+                self.parse_testcase(el, ts)
+            if el.tag == 'properties':
+                self.parse_properties(el, ts)
+
+    def parse_testcase(self, el, ts):
+        tc = self.TC_CLASS(el.attrib['classname'], el.attrib['name'])
+        tc.seed('success', trace=el.text or None)
+        tc.time = to_timedelta(el.attrib.get('time'))
+        restags = False
+        for e in el:
+            if e.tag in ('failure', 'error', 'skipped'):
+                tc = self.TC_CLASS(el.attrib['classname'], el.attrib['name'])
+                result = e.tag
+                typename = e.attrib.get('type')
+                message = e.attrib.get('message')
+                tc.seed(result, typename, message, e.text or None)
+                tc.time = to_timedelta(el.attrib.get('time'))
+                ts.addTest(tc)
+                restags = True
+            if e.tag == 'system-out':
+                tc.stdout = e.text.strip()
+            if e.tag == 'system-err':
+                tc.stderr = e.text.strip()
+        if not restags:
+            ts.addTest(tc)
+
+    def parse_properties(self, el, ts):
+        for e in el:
+            if e.tag == 'property':
+                assert e.attrib['name'] not in ts.properties
+                ts.properties[e.attrib['name']] = e.attrib['value']
+
 
 def parse(source):
     return Parser().parse(source)
